// otp_state.dart
import 'package:equatable/equatable.dart';

abstract class OtpState extends Equatable {
  const OtpState();

  @override
  List<Object> get props => [];
}

class OtpInitial extends OtpState {}

class OtpCodeReceived extends OtpState {
  final String code;

  const OtpCodeReceived(this.code);

  @override
  List<Object> get props => [code];
}

class OtpSubmitting extends OtpState {}

class OtpSubmissionSuccess extends OtpState {}

class OtpSubmissionFailure extends OtpState {
  final String error;

  const OtpSubmissionFailure(this.error);

  @override
  List<Object> get props => [error];
}
